@@ -103,7 +103,7 @@ class CustomLogger(Logger):
 
 
 class Run():
-    def __init__(self, name="", user_id="", lab_id="", org_id="", token="", flush_interval_seconds=5,
+    def __init__(self, name="", user_id="", lab_id="", org_id="", user_token="", flush_interval_seconds=5,
                  sys_stat_sample_size=1, sys_stat_sample_interval=2, local_path='', write_logs_to_local=False,
                  remote_path='', buffer_all_logs=False):
         if name == '':
@@ -401,7 +401,7 @@ class Run():
 
             path_artifact = '/api/dataset-upload-token?subType=artifact'
             endpoint_get_token = self.remote_path.replace(
-                '/api/runs', path_artifact) + '&token=' + self.token
+                '/api/runs', path_artifact) + '&token=' + self.user_token
             oss_config = requests.get(endpoint_get_token)
             AK = oss_config['accessKeyId']
             SK = oss_config['secretAccessKey']
